@@ -1,9 +1,9 @@
 #' plot.summaryAlphaPart.R
 #'
-#' A function to plot summary of partitioned additive genetic values.
+#' A function to plot summary of partitioned breeding values.
 #'
 #' @details
-#' Information in summaries of partitions of additive genetic values can be
+#' Information in summaries of partitions of breeding values can be
 #' overhelming due to a large volume of numbers. Plot method can be used to
 #' visualise this data in eye pleasing way using ggplot2
 #' graphics.
@@ -19,7 +19,6 @@
 #' @param ylab Character, y-axis label; can be a vector of several labels if there are more traits in \code{x} (recycled!).
 #' @param xlim Numeric, a vector of two values with x-axis limits; use a list of vectors for more traits.
 #' @param ylim Numeric, a vector of two values with y-axis limits; use a list of vectors for more traits.
-#' @param ylimRel Numeric, a vector of two values with y-axis limits for relative values; use a list of vectors for more traits.
 #' @param color Character, color names; by default a set of 54 colors is predefined from the \pkg{RColorBrewer} package;
 #' in addition a black colour is attached at the begining for the overall trend; if there are more paths than
 #' colors then recycling occours.
@@ -41,8 +40,7 @@
 #' @example inst/examples/examples_plotSummaryAlphaPart.R
 #'
 #' @return A list of ggplot objects that can be further modified or displayed.
-#' For each trait in \code{x} there are two plots (one for absolute values and one for
-#' relative values).
+#' For each trait in \code{x} there is one plot visualising summarized values.
 #'
 #' @useDynLib AlphaPart, .registration = TRUE
 #' @importFrom Rcpp sourceCpp
@@ -65,7 +63,6 @@ plot.summaryAlphaPart <- function (
   ylab=NULL,
   xlim=NULL,
   ylim=NULL,
-  ylimRel=NULL,
   color,
   lineSize=1,
   lineType=1,
@@ -87,10 +84,6 @@ plot.summaryAlphaPart <- function (
   nP    <- x$info$nP
   ret   <- vector(mode="list", length=nT)
   names(ret) <- x$info$lT
-  for (i in 1:nT) {
-    ret[[i]] <- vector(mode="list", length=2)
-    names(ret[[i]]) <- c("abs", "rel")
-  }
 
   ## Axis labels
   if (!is.null(xlab) && length(xlab) > 1) stop("you can provide only one value for 'xlab'")
@@ -138,104 +131,94 @@ plot.summaryAlphaPart <- function (
 
   ## --- Create plots ---
 
-  for (rel in c(FALSE, TRUE)) { ## loop over absolute and relative plots
 
-    ## Absolute and relative ylim
-    if (rel) {
-      ylimT <- ylimRel
-    } else {
-      ylimT <- ylim
+  ## Ylim
+  ylimT <- ylim
+
+
+  for (i in 1:nT) { ## loop over traits
+    colorI <- color
+    lineTypeI <- lineType
+    ## Prepare data
+    tmp0 <- x[[i]]
+    ## Make sure that path has a name "N"
+    tmpCol <- colnames(tmp0)
+    test <- tmpCol %in% "N"
+    if (sum(test) > 1) {
+      tmpCol[test & cumsum(test) == 2] <- "N."
+      colnames(tmp0) <- tmpCol
+      warning("changing path name from 'N' to 'N.'")
     }
-
-    for (i in 1:nT) { ## loop over traits
-      colorI <- color
-      lineTypeI <- lineType
-      ## Prepare data
-      tmp0 <- x[[i]][[rel + 1]]
-      ## Make sure that path has a name "N"
-      tmpCol <- colnames(tmp0)
-      test <- tmpCol %in% "N"
-      if (sum(test) > 1) {
-        tmpCol[test & cumsum(test) == 2] <- "N."
-        colnames(tmp0) <- tmpCol
-        warning("changing path name from 'N' to 'N.'")
-      }
-      tmp <- melt(tmp0[, !(colnames(tmp0) %in% "N")], id=by)
-      colnames(tmp) <- c("by", "path", "trait")
-      if (is.logical(sortValue)) {
-        if (sortValue) {
-          nC <- ncol(tmp0)
-          pathStat <- sapply(X=tmp0[, (nC - nP + 1):nC], FUN=sortValueFUN, na.rm=TRUE)
-          levs <- names(sort(pathStat, decreasing=sortValueDec))
-          tmp$path <- factor(tmp$path, levels=c(x$info$labelSum, levs))
-          if (!is.null(lineTypeList)) { ## fiddle with upper (color) and lower (line type) level of paths
-            levs2X <- names(lineTypeList); levs2X <- levs2X[levs2X != "def"]
-            levs1 <- levs2 <- levs
-              for (k in levs2X) {
-              j <- paste(k, "$", sep="") ## lower label mark needs to be at the end of path name!!!
-              levs2[grep(pattern=j, x=levs1)] <- k
-              levs1 <- sub(pattern=j, replacement="", x=levs1)
-            }
-            levs2[!levs2 %in% levs2X] <- "def"
-            levs1X <- unique(levs1)
-            colorList <- as.list(color[-1][1:length(levs1X)]); names(colorList) <- levs1X
-            colorI <- c("black", unlist(colorList[levs1])); names(colorI) <- NULL
-            lineTypeI <- c(lineTypeList$def, unlist(lineTypeList[levs2])); names(lineTypeI) <- NULL
+    tmp <- melt(tmp0[, !(colnames(tmp0) %in% "N")], id=by)
+    colnames(tmp) <- c("by", "path", "trait")
+    if (is.logical(sortValue)) {
+      if (sortValue) {
+        nC <- ncol(tmp0)
+        pathStat <- sapply(X=tmp0[, (nC - nP + 1):nC], FUN=sortValueFUN, na.rm=TRUE)
+        levs <- names(sort(pathStat, decreasing=sortValueDec))
+        tmp$path <- factor(tmp$path, levels=c(x$info$labelSum, levs))
+        if (!is.null(lineTypeList)) { ## fiddle with upper (color) and lower (line type) level of paths
+          levs2X <- names(lineTypeList); levs2X <- levs2X[levs2X != "def"]
+          levs1 <- levs2 <- levs
+            for (k in levs2X) {
+            j <- paste(k, "$", sep="") ## lower label mark needs to be at the end of path name!!!
+            levs2[grep(pattern=j, x=levs1)] <- k
+            levs1 <- sub(pattern=j, replacement="", x=levs1)
           }
+          levs2[!levs2 %in% levs2X] <- "def"
+          levs1X <- unique(levs1)
+          colorList <- as.list(color[-1][1:length(levs1X)]); names(colorList) <- levs1X
+          colorI <- c("black", unlist(colorList[levs1])); names(colorI) <- NULL
+          lineTypeI <- c(lineTypeList$def, unlist(lineTypeList[levs2])); names(lineTypeI) <- NULL
         }
-      } else {
-        tmp$path <- factor(tmp$path, levels=c(x$info$labelSum, sortValue))
       }
-
-      ## Removing overall trend when plotting relative results
-      if (rel | !addSum) {
-        tmp <- tmp[!(tmp$path == x$info$labelSum), ]          ## data
-        tmp$path <- factor(tmp$path, levels=levels(tmp$path)[-1])
-        colorI <- colorI[-1]                                  ## black color
-        lineTypeI <- lineTypeI[-1]                            ## line type
-      }
-
-      ## Prepare plot
-      #trait in "" since it is not defined
-      trait <- tmp$trait
-      p <- qplot(x=by, y=trait, group=path, data=tmp, color=path, linetype=path, geom="line")
-
-      p <- p + geom_line(size=lineSize)
-
-      p <- p + xlab(label=ifelse(is.null(xlab), by,    xlab))
-      p <- p + ylab(label=ifelse(is.null(ylab), lT[i], ylab[i])) #lT[i] is the TRAIT!!!
-
-      if (!is.null(xlim)) {
-        if (is.list(xlim)) {
-          xlimI <- xlim[[i]]
-        } else {
-          xlimI <- xlim
-        }
-        p <- p + scale_x_continuous(limits=xlimI)
-      }
-
-      if (!is.null(ylimT)) {
-        if (is.list(ylimT)) {
-          ylimI <- ylimT[[i]]
-        } else {
-          ylimI <- ylimT
-        }
-        p <- p + scale_y_continuous(limits=ylimI)
-      }
-
-      if (useDirectLabels) p <- directlabels::direct.label(p=p, method=method)
-
-      ## This needs to follow direct.label
-      p <- p + scale_colour_manual(values=colorI,
-      name=ifelse(is.null(labelPath), path, labelPath))
-
-      p <- p + scale_linetype_manual(values=lineTypeI,
-      name=ifelse(is.null(labelPath), path, labelPath))
-
-      ret[[i]][[rel + 1]] <- p
+    } else {
+      tmp$path <- factor(tmp$path, levels=c(x$info$labelSum, sortValue))
     }
-  }
 
+
+    ## Prepare plot
+    #trait in "" since it is not defined
+    trait <- tmp$trait
+    p <- qplot(x=by, y=trait, group=path, data=tmp, color=path, linetype=path, geom="line")
+
+    p <- p + geom_line(size=lineSize)
+
+    p <- p + xlab(label=ifelse(is.null(xlab), by,    xlab))
+    p <- p + ylab(label=ifelse(is.null(ylab), lT[i], ylab[i])) #lT[i] is the TRAIT!!!
+
+    if (!is.null(xlim)) {
+      if (is.list(xlim)) {
+        xlimI <- xlim[[i]]
+      } else {
+        xlimI <- xlim
+      }
+      p <- p + scale_x_continuous(limits=xlimI)
+    }
+
+    if (!is.null(ylimT)) {
+      if (is.list(ylimT)) {
+        ylimI <- ylimT[[i]]
+      } else {
+        ylimI <- ylimT
+      }
+      p <- p + scale_y_continuous(limits=ylimI)
+    }
+
+    if (useDirectLabels) p <- directlabels::direct.label(p=p, method=method)
+
+    ## This needs to follow direct.label
+    p <- p + scale_colour_manual(values=colorI,
+    name=ifelse(is.null(labelPath), path, labelPath))
+
+    p <- p + scale_linetype_manual(values=lineTypeI,
+    name=ifelse(is.null(labelPath), path, labelPath))
+    
+    ret[[i]] <- p
+  
+}
+
+  
   ## --- Return ---
 
   class(ret) <- c("plotSummaryAlphaPart", class(ret))
